@@ -11,6 +11,7 @@ from lyrebird.log import get_logger
 from jinja2 import Template
 from lyrebird.application import config
 from lyrebird.mock.handlers import snapshot_helper
+from lyrebird.mock.dm.jsonpath import jsonpath
 
 
 PROP_FILE_NAME = '.lyrebird_prop'
@@ -219,33 +220,31 @@ class DataManager:
     def _is_match_rule(self, flow, rules):
         if not rules:
             return False
-        for rule_key in rules:
-            pattern = rules[rule_key]
-            target = self._get_rule_target(rule_key, flow)
-            if not target:
+        for rule_key, pattern in rules.items():
+            targets = self._get_rule_targets(rule_key, flow)
+            if not targets:
                 return False
+            if not self._is_target_pattern_matched(pattern, targets):
+                return False
+        return True
 
+    def _get_rule_targets(self, rule_key, flow):
+        search_res = jsonpath.search(flow, rule_key)
+        if not search_res:
+            return None
+        return [s.node for s in search_res if s.node]
+
+    def _is_target_pattern_matched(self, pattern, targets):
+        for target in targets:
             try:
                 search_result = re.search(pattern, target)
             except:
                 logger.warning(f'Illegal regular match in mock data!\n {traceback.format_exc()}')
                 return False
-
             if not search_result:
                 return False
         return True
 
-    def _get_rule_target(self, rule_key, flow):
-        prop_keys = rule_key.split('.')
-        result = flow
-        for prop_key in prop_keys:
-            if not isinstance(result, dict):
-                return
-            result = result.get(prop_key)
-            if not result:
-                return None
-        return result
-
     # -----
     # Data tree operations
     # -----
